#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 03-07-2014

@author: agnieszka
'''

class ConLLToken():
    def __init__(self, line):
        if type(line) != type([]):
            parts = line.split("\t")
        else:
            parts = line
        
        if len(parts) < 10:
            print "Problem with parts:", parts, "len of parts:", len(parts), line
            return
        
        if "-" in parts[0]:
            start,end = parts[0].split("-")
            self.tokId = range(int(start), int(end) + 1)
        else:
            self.tokId = int(parts[0])
        
        self.orth = parts[1]
        self.lemma = parts[2]
        self.pos = parts[3]
        self.langPos = parts[4]
        self.morph = parts[5]
        self.headId = int(parts[6]) if parts[6] != '_' else -1
        self.dep = parts[7]
        self.enhanced = parts[8]

        if len(parts) > 10:
            self.supertag = parts[10]
        else:
            self.supertag = None

        if len(parts) > 11:
            self.sentId = parts[11]
        else:
            self.sentId = None

        if len(parts) > 12:
            self.docId = parts[12]
        else:
            self.docId = None

    def __str__(self):
        return "\t".join(self.buildParts())
    
    def buildParts(self):
        parts = [ self.getId(),
                 self.orth,
                 self.lemma,
                 self.pos,
                 self.langPos,
                 self.morph,
                 self.__niceId(self.headId),
                 self.dep,
                 self.enhanced ]

        parts += [ "_" ] * ( 10 - len(parts) )

        if self.supertag != None:
            parts.append(self.supertag)
        else:
            parts.append("_")

        if self.sentId != None:
            parts.append(str(self.sentId))

        if self.docId != None:
            parts.append(self.docId)

        return parts
    
    def getId(self):
        if type(self.tokId) == type([]):
            result = str(self.tokId[0]) + "-" + str(self.tokId[-1])
            return result

        return str(self.tokId)
    
    def __niceId(self, aId):
        if aId == -1:
            return "_"
        else:
            return str(aId)

    def getTokPos(self):
        return self.tokId - 1

    def getHeadPos(self):
        return self.headId - 1
