#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Created on 21-07-2018

@author: agnieszka
'''

import sys
import reader

def cleanTag(tag):
    result = [ ]
    for t in tag.split(":")[1:]:
        if t not in [ "perf", "imperf", "com" ]:
            result.append(t)
            
    return ":".join(result)
            
def sameTags(tag1, tag2):
    return tag1 == tag2

def findCase(tag):
    for c in [ "nom", "acc", "inst", "gen", "loc", ]:
        if c in tag:
            return c
    
def sameCase(tag1, tag2):
    return findCase(tag1) == findCase(tag2)

def collectChildren(sent):
    children = { }
    for tok in sent:
        if tok.headId not in  children:
            children[tok.headId] = [ ]
            
        children[tok.headId].append(tok)
    return children
            
def predict(fileName, outFile):
    lreader = reader.LazySentenceReader(open(fileName, "r"))
    
    sent = lreader.next()
    out = open(outFile, "w")
    while sent:
        children = collectChildren(sent)
        
        for tok in sent:                
            lbls = [ ]
            
            enhanced = [ ( tok.headId, tok.dep) ]
            lbls.append(tok.dep)
            
            if tok.dep == "conj":
                headTok = sent[tok.getHeadPos()]
                enhanced.append((headTok.headId, headTok.dep))
                lbls.append(headTok.dep)
                
            elif tok.dep in [ "case", "discourse:comment", "nsubj", "case", "mark", "advmod", "obl", "cop", "advcl", "obj", "amod" ]:
                
                for child in children[tok.headId]:
                    if child.tokId == tok.tokId:
                        continue
                    
                    if child.tokId in children:
                        grand = { g.dep : g.orth for g in children[child.tokId] }
                    else:
                        grand = { }
                        
                    if child.dep == "conj":
                        if tok.dep != "case" and not sameTags(child.langPos, sent[tok.getHeadPos()].langPos):
                            if tok.dep == "nsubj":
                                wasCop = False
                                for otherChild in children[tok.headId]:
                                    if otherChild.tokId == tok.tokId or otherChild.tokId == child.tokId:
                                        continue
                                    
                                    if otherChild.dep == "cop" and sameTags(child.langPos, otherChild.langPos):
                                        wasCop = True
                                    
                                if not wasCop:
                                    continue
                            else:
                                continue
                        
                        elif tok.dep == "case" and "case" in grand:
                            continue
                        elif tok.dep == "advmod" and tok.tokId > tok.headId:
                            continue
                        elif tok.dep == "advmod" and "advmod" in grand:
                            continue
                        elif tok.dep == "advmod" and "discourse:comment" in grand:
                            continue 
                        elif tok.dep == "advmod" and "cc" in grand and grand["cc"] != "i":
                            continue
                        elif tok.dep == "nsubj" and "nsubj" in grand and "cc" in grand:
                            continue
                        elif tok.dep == "obl" and child.tokId > tok.tokId and tok.headId < tok.tokId:
                            continue
                        elif tok.dep == "obj" and child.tokId > tok.tokId:
                            continue
                        elif tok.dep == "amod" and child.tokId > tok.tokId and tok.headId < tok.tokId:
                            continue
                        
                        enhanced.append((child.tokId, tok.dep))
                        lbls.append(tok.dep)
            
         
            newTag = "|".join([ str(tId) + ":" + dep for (tId, dep) in sorted(enhanced)])
            tok.enhanced = newTag
            
        for tok in sent:
            out.write(str(tok) + "\n")
        out.write("\n")
        
        sent = lreader.next()

if __name__ == '__main__':
    args = sys.argv[1:]

    conllFile = args[0]
    outFile = args[1]
    predict(conllFile, outFile)
