#!/usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 03-07-2014

@author: agnieszka
'''

from conlltoken import ConLLToken

def conllu_omit(token):
    return conllu_comment(token) or "-" in token[0] or "." in token[0]

def conllu_comment(token):
    return "".join(token).startswith("#")
            
def read_sentences( stream, delim="\t" ):
    sentence = []    
    for line in stream:
        line = line.strip()
        if line:
            sentence.append(line.split(delim))
        elif sentence:
            yield sentence
            sentence = []
    if sentence:
        yield sentence

class LazySentenceReader():
    def __init__(self, f, omit=True):
        self.__f = f
        self.__el = None
        self.__omit=omit
        self.sentNr=0
        
    def top(self):
        return self.__el
    
    def next(self):
        sentence = [ ]
        line = self.__f.readline().strip()
        while line:
            if self.__omit or conllu_comment(line.split()):
                if conllu_omit(line.split()):
                    line = self.__f.readline().strip()
                    continue
            
            sentence.append(ConLLToken(line))
            line = self.__f.readline().strip()
            
        self.__el = sentence
        self.sentNr+=1
        return sentence

class LazyTokenReader():
    def __init__(self, f,omit=True):
        self.reader = LazySentenceReader(f,omit)
        self.__pos = None
        
    def top(self):
        return self.reader.top()[self.__pos]
    
    def next(self):
        if self.reader.top() == None or self.__pos >= len(self.reader.top()):
            self.reader.next()
            self.__pos = 0
        
        if not self.reader.top():
            return None
        
        result = self.reader.top()[self.__pos]
        self.__pos += 1
        return result
    
    def getSent(self):
        return self.reader.top()
    

